## 0.5.3 (2021-05-13)

- Fixed `stringifyStream()` and `stringifyInfo()` to work properly when replacer is an allowlist
- `parseChunked()`
    - Fixed wrong parse error when chunks are splitted on a whitespace inside an object or array (#6, @alexei-vedder)
    - Fixed corner cases when wrong placed or missed comma doesn't cause to parsing failure

## 0.5.2 (2020-12-26)

- Fixed `RangeError: Maximum call stack size exceeded` in `parseChunked()` on very long arrays (corner case)

## 0.5.1 (2020-12-18)

- Fixed `parseChunked()` crash when input has trailing whitespaces

## 0.5.0 (2020-12-05)

- Added support for Node.js 10

## 0.4.0 (2020-12-04)

- Added `parseChunked()` method
- Fixed `stringifyInfo()` to not throw when meet unknown value type

## 0.3.2 (2020-10-26)

- Added missed file for build purposes

## 0.3.1 (2020-10-26)

- Changed build setup to allow building by any bundler that supports `browser` property in `package.json`
- Exposed version

## 0.3.0 (2020-09-28)

- Renamed `info()` method into `stringifyInfo()`
- Fixed lib's distribution setup

## 0.2.0 (2020-09-28)

- Added `dist` version to package (`dist/json-ext.js` and `dist/json-ext.min.js`)

## 0.1.1 (2020-09-08)

- Fixed main entry point

## 0.1.0 (2020-09-08)

- Initial release
